@@ -1,9 +1,11 @@
 import os
 from urllib.parse import urlparse
+import json
 
 from .abstract_deployer import AbstractDeployer
 from spark_etl import Build
 from spark_etl.exceptions import SparkETLDeploymentFailure
+import spark_etl
 
 import boto3
 
@@ -17,14 +19,17 @@ class S3Deployer(AbstractDeployer):
 
     def deploy(self, build_dir, deployment_location):
         o = urlparse(deployment_location)
-        if o.scheme != 's3':
-            raise SparkETLDeploymentFailure("deployment_location must be in s3")
+        if o.scheme not in ('s3', 's3a'):
+            raise SparkETLDeploymentFailure("deployment_location must be in s3 or s3a")
 
         build = Build(build_dir)
 
         args = {}
         if 'aws_account' in self.config:
-            with open(self.config['aws_account'], "rt") as f:
+            with open(
+                os.path.expandvars(os.path.expanduser(self.config['aws_account'])),
+                "rt"
+            ) as f:
                 aws_account_content     = json.load(f)
                 args['aws_access_key_id']       = aws_account_content['aws_access_key_id']
                 args['aws_secret_access_key']   = aws_account_content['aws_secret_access_key']
@@ -43,12 +48,15 @@ class S3Deployer(AbstractDeployer):
             local_filename = os.path.join(build.build_dir, artifact)
             object_name = os.path.join(s3_dirname, artifact)
 
-            print(f"{local_filename}  ==> {object_name}")
+            target = os.path.join(deployment_location, artifact)
+            print(f"{local_filename}  ==> {target}")
             s3_client.upload_file(local_filename, bucket_name, object_name)
 
+        spark_etl_dir = os.path.dirname(os.path.abspath(spark_etl.__file__))
 
-        local_filename = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'job_loader.py')
+        local_filename = os.path.join(spark_etl_dir, 'core', 'loader_util', 'resources', 'job_loader.py')
         object_name = os.path.join(s3_dirname, "job_loader.py")
-        print(f"{local_filename}  ==> {object_name}")
+        target = os.path.join(deployment_location, "job_loader.py")
+        print(f"{local_filename}  ==> {target}")
         s3_client.upload_file(local_filename, bucket_name, object_name)
 
