@@ -5,7 +5,7 @@ import shutil
 
 from spark_etl.deployers import AbstractDeployer
 from spark_etl import Build
-
+import spark_etl
 
 class LocalDeployer(AbstractDeployer):
     """
@@ -35,21 +35,22 @@ class LocalDeployer(AbstractDeployer):
         # copy artifacts
         target_dir = os.path.join(deployment_location, build.version)
         if os.path.isdir(target_dir):
-            shutil.rmtree(target_dir)
-        os.makedirs(target_dir)
+            for fname in os.listdir(target_dir):
+                fullname = os.path.join(target_dir, fname)
+                if os.path.isdir(fullname):
+                    shutil.rmtree(fullname)
+                else:
+                    os.remove(fullname)
+        else:
+            os.makedirs(target_dir)
         for artifact in build.artifacts:
             src = os.path.join(build_dir, artifact)
             dst = os.path.join(target_dir, artifact)
-            print(f"Copy from {src} to {dst}")
+            print(f"{src}  ==> {dst}")
             shutil.copyfile(src, dst)
 
-        src = os.path.join(os.path.dirname(os.path.abspath(__file__)), "job_loader.py")
+        spark_etl_dir = os.path.dirname(os.path.abspath(spark_etl.__file__))
+        src = os.path.join(spark_etl_dir, 'core', 'loader_util', 'resources', 'job_loader.py')
         dst = os.path.join(target_dir, "job_loader.py")
+        print(f"{src}  ==> {dst}")
         shutil.copyfile(src, dst)
-        print(f"Copy from {src} to {dst}")
-
-        print("Deployment is done")
-
-
-
-
