@@ -13,7 +13,7 @@ from oci_core import get_os_client, get_df_client, os_upload, os_upload_json
 from spark_etl.deployers import AbstractDeployer
 from spark_etl import Build, SparkETLDeploymentFailure
 from .tools import check_response, remote_execute
-from spark_etl.misc_tools import read_textfile
+from spark_etl.misc_tools import read_textfile, get_filename
 
 def _save_json_temp(payload):
     # save a dict to temporary json file, and return filename
@@ -157,7 +157,7 @@ class DataflowDeployer(AbstractDeployer):
             )
             os_upload(
                 os_client,
-                oci_config['key_file'],
+                get_filename(oci_config['key_file']),
                 namespace,
                 bucket,
                 "oci_api_key.pem",
